@@ -9,24 +9,8 @@ def adapter_logger(function):
     @wraps(function)
     def wrapper(*args, **kwargs):
         logger = TmsPluginManager.get_logger()
-        parameters = {}
-        args_default_values = inspect.getfullargspec(function).defaults
 
-        if args or args_default_values:
-            all_keys = inspect.getfullargspec(function).args
-            all_args = list(args)
-
-            if args_default_values:
-                all_args += list(args_default_values[len(args) - (len(all_keys) - len(args_default_values)):])
-
-            method_args = [arg_name for arg_name in all_keys if arg_name not in list(kwargs)]
-
-            for index in range(0, len(method_args)):
-                parameters[method_args[index]] = str(all_args[index])
-
-        if kwargs:
-            for key, parameter in kwargs.items():
-                parameters[key] = str(parameter)
+        parameters = get_function_parameters(function, *args, **kwargs)
 
         message = f'Method "{function.__name__}" started'
 
@@ -46,3 +30,26 @@ def adapter_logger(function):
 
         return result
     return wrapper
+
+def get_function_parameters(function, *args, **kwargs):
+    parameters = {}
+    args_default_values = inspect.getfullargspec(function).defaults
+
+    if args or args_default_values:
+        all_keys = inspect.getfullargspec(function).args
+        all_args = list(args)
+
+        if args_default_values:
+            all_args += list(args_default_values[len(args) - (len(all_keys) - len(args_default_values)):])
+
+        method_args = [arg_name for arg_name in all_keys if arg_name not in list(kwargs)]
+
+        if len(method_args) == len(all_args):
+            for index in range(0, len(method_args)):
+                parameters[method_args[index]] = str(all_args[index])
+
+    if kwargs:
+        for key, parameter in kwargs.items():
+            parameters[key] = str(parameter)
+
+    return parameters
